@@ -2,7 +2,7 @@ from docker_image import reference
 
 from dagster import Field, StringSource
 from dagster import _check as check
-from dagster.utils import merge_dicts
+from dagster._utils import merge_dicts
 
 from .container_context import DOCKER_CONTAINER_CONTEXT_SCHEMA
 
